@@ -27,12 +27,16 @@ public:
         DescriptionRole,
         ViewCountRole,
         SubscriberCountRole,
-        SubscriptionRole
+        SubscriptionRole,
+        ServiceRole
     };
 
 public:
     explicit AbstractUserListModel(QObject *parent = 0);
     ~AbstractUserListModel();
+#if QT_VERSION >= 0x050000
+    QHash<int, QByteArray> roleNames() const;
+#endif
     int rowCount(const QModelIndex &parent = QModelIndex()) const;
     QVariant data(const QModelIndex &index, int role) const;
     Q_INVOKABLE QVariant data(int row, const QByteArray &role) const;
@@ -60,6 +64,7 @@ protected:
     ThumbnailCache *m_cache;
 #endif
     QList< QSharedPointer<UserItem> > m_list;
+    QHash<int, QByteArray> m_roleNames;
 };
 
 #endif // ABSTRACTUSERLISTMODEL_H
