@@ -1,6 +1,6 @@
 #include "dailymotion.h"
 #include "json.h"
-#include "utils.h"
+#include "definitions.h"
 #include <QNetworkRequest>
 #include <QNetworkReply>
 #include <QStringList>
@@ -18,7 +18,7 @@
 
 using namespace QtJson;
 
-Dailymotion* dailymotionInstance = 0;
+Dailymotion* Dailymotion::self = 0;
 
 const QByteArray CLIENT_ID("808ed79fa59e10f3952e");
 const QByteArray CLIENT_SECRET("5753a7aa0fb0772b628d160aabe3da6059f97375");
@@ -38,8 +38,8 @@ Dailymotion::Dailymotion(QObject *parent) :
     m_busy(false),
     m_cancelled(false)
 {
-    if (!dailymotionInstance) {
-        dailymotionInstance = this;
+    if (!self) {
+        self = this;
     }
 
     m_queryOrders[Queries::Relevance] = "relevance";
@@ -53,7 +53,7 @@ Dailymotion::~Dailymotion() {
 }
 
 Dailymotion* Dailymotion::instance() {
-    return dailymotionInstance;
+    return !self ? new Dailymotion : self;
 }
 
 void Dailymotion::setBusy(bool isBusy, const QString &message, int numberOfOperations) {
@@ -114,7 +114,7 @@ QNetworkReply* Dailymotion::createReply(QUrl feed, int offset) {
     qDebug() << feed;
 
     QNetworkRequest request(feed);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
 
     return this->networkAccessManager()->get(request);
 }
@@ -205,7 +205,7 @@ QNetworkReply* Dailymotion::createSearchReply(int queryType, const QString &quer
     qDebug() << url;
 
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
 
     return this->networkAccessManager()->get(request);
 }
@@ -276,7 +276,7 @@ void Dailymotion::signIn(const QString &displayName, const QUrl &response) {
                         "&grant_type=authorization_code");
 
         QNetworkRequest request(url);
-        request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+        request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
         request.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
         QNetworkReply *reply = this->networkAccessManager()->post(request, body);
         this->connect(reply, SIGNAL(finished()), this, SLOT(checkIfSignedIn()));
@@ -298,7 +298,7 @@ void Dailymotion::signIn(const QString &displayName, const QString &user, const
                     "&grant_type=password");
 
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     request.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
     QNetworkReply *reply = this->networkAccessManager()->post(request, body);
     this->connect(reply, SIGNAL(finished()), this, SLOT(checkIfSignedIn()));
@@ -345,7 +345,7 @@ void Dailymotion::refreshAccessToken() {
                     "&grant_type=refresh_token");
 
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     request.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
     QNetworkReply *reply = this->networkAccessManager()->post(request, body);
     this->connect(reply, SIGNAL(finished()), this, SLOT(checkTokenRefresh()));
@@ -399,7 +399,7 @@ void Dailymotion::signOut() {
     this->setBusy(true, tr("Signing out"));
     QUrl url("https://api.dailymotion.com/logout");
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     request.setRawHeader("Authorization", "OAuth " + this->accessToken().toUtf8());
     QNetworkReply* reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(checkIfSignedOut()));
@@ -432,7 +432,7 @@ void Dailymotion::postRequest(const QUrl &url, const QByteArray &data) {
     qDebug() << url;
     qDebug() << data;
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     request.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
     request.setRawHeader("Authorization", "OAuth " + this->accessToken().toUtf8());
     QNetworkReply* reply = this->networkAccessManager()->post(request, data);
@@ -443,7 +443,7 @@ void Dailymotion::postRequest(const QUrl &url, const QByteArray &data) {
 void Dailymotion::deleteRequest(const QUrl &url) {
     qDebug() << url;
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     request.setRawHeader("Authorization", "OAuth " + this->accessToken().toUtf8());
     QNetworkReply* reply = this->networkAccessManager()->deleteResource(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(postFinished()));
@@ -508,7 +508,7 @@ void Dailymotion::getPlaylists(int offset) {
     url.addQueryItem("access_token", accessToken());
 #endif
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(addPlaylists()));
 }
@@ -617,7 +617,7 @@ void Dailymotion::getGroups(int offset) {
     url.addQueryItem("access_token", accessToken());
 #endif
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(addGroups()));
 }
@@ -739,7 +739,7 @@ void Dailymotion::getSubscriptions(int offset) {
     url.addQueryItem("access_token", accessToken());
 #endif
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(addSubscriptions()));
 }
@@ -857,7 +857,7 @@ void Dailymotion::getFullVideo(QString id) {
     url.addQueryItem("family_filter", "false");
 #endif
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(checkFullVideo()));
     this->connect(this, SIGNAL(currentOperationCancelled()), reply, SLOT(deleteLater()));
@@ -931,7 +931,7 @@ void Dailymotion::getVideoMetadata(const QString &id) {
     url.addQueryItem("access_token", this->accessToken());
 #endif
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(checkVideoMetadata()));
 }
@@ -993,7 +993,7 @@ void Dailymotion::getCurrentUserProfile() {
     url.addQueryItem("access_token", accessToken());
 #endif
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(checkCurrentUserProfile()));
 }
@@ -1058,7 +1058,7 @@ void Dailymotion::getUserProfile(const QString &id) {
     url.addQueryItem("fields", DAILYMOTION_USER_PROFILE_FIELDS);
 #endif
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(checkUserProfile()));
 }
@@ -1429,7 +1429,7 @@ void Dailymotion::getPlaylistForCache(const QString &id) {
     url.addQueryItem("fields", DAILYMOTION_PLAYLIST_FIELDS);
 #endif
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(checkCachePlaylist()));
 }
@@ -1527,7 +1527,7 @@ void Dailymotion::getGroupForCache(const QString &id) {
     url.addQueryItem("fields", DAILYMOTION_GROUP_FIELDS);
 #endif
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(checkCacheGroup()));
 }
@@ -1629,7 +1629,7 @@ void Dailymotion::getAddedComment(const QString &id) {
     url.addQueryItem("fields", DAILYMOTION_COMMENT_FIELDS);
 #endif
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(checkAddedComment()));
 }
@@ -1696,7 +1696,7 @@ void Dailymotion::getSubscriptionForCache(const QString &id) {
     url.addQueryItem("fields", DAILYMOTION_USER_FIELDS);
 #endif
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(checkCacheSubscription()));
 }
@@ -1822,7 +1822,7 @@ void Dailymotion::getVideosFromIds(QStringList ids) {
     url.addQueryItem("limit", "100");
 #endif
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(checkFullVideos()));
 }
