@@ -38,6 +38,9 @@ class PlaylistItem : public QObject
     Q_PROPERTY(QUrl thumbnailUrl
                READ thumbnailUrl
                NOTIFY thumbnailUrlChanged)
+    Q_PROPERTY(QUrl largeThumbnailUrl
+               READ largeThumbnailUrl
+               NOTIFY largeThumbnailUrlChanged)
     Q_PROPERTY(QString date
                READ date
                NOTIFY dateChanged)
@@ -78,6 +81,8 @@ public:
     inline void setDuration(int duration) { m_duration = duration; emit durationChanged(duration); }
     inline QUrl thumbnailUrl() const { return m_thumbnailUrl; }
     inline void setThumbnailUrl(const QUrl &url) { m_thumbnailUrl = url; emit thumbnailUrlChanged(url); }
+    inline QUrl largeThumbnailUrl() const { return m_largeThumbnailUrl; }
+    inline void setLargeThumbnailUrl(const QUrl &url) { m_largeThumbnailUrl = url; emit largeThumbnailUrlChanged(url); }
     inline QString date() const { return m_date; }
     inline void setDate(const QString &date) { m_date = date; emit dateChanged(date); }
     inline int videoCount() const { return m_videoCount; }
@@ -96,6 +101,7 @@ signals:
     void descriptionChanged(const QString &description);
     void durationChanged(int duration);
     void thumbnailUrlChanged(const QUrl &url);
+    void largeThumbnailUrlChanged(const QUrl &url);
     void dateChanged(const QString &date);
     void videoCountChanged(int count);
     void isPrivateChanged(bool isPrivate);
@@ -112,6 +118,7 @@ private:
     int m_duration;
     QString m_date;
     QUrl m_thumbnailUrl;
+    QUrl m_largeThumbnailUrl;
     int m_videoCount;
     bool m_private;
     Services::VideoService m_service;
