@@ -1,6 +1,6 @@
 #include "sharing.h"
 #include "json.h"
-#include "utils.h"
+#include "definitions.h"
 #include "oauth.h"
 #include <QNetworkAccessManager>
 #include <QNetworkRequest>
@@ -24,11 +24,11 @@
 using namespace QtJson;
 using namespace QtOAuth;
 
-Sharing* sharingInstance = 0;
+Sharing* Sharing::self = 0;
 
-const QRegExp YOUTUBE_SHARING_RE("(http(s|)://(www.|m.|)youtube.com/(v/|.+)(v=|)|http://youtu.be/)");
-const QRegExp DAILYMOTION_SHARING_RE("(http(s|)://(www.|)dailymotion.com/video/|http://dai.ly/)\\w{6}");
-const QRegExp VIMEO_SHARING_RE("http(s|)://vimeo.com/\\d+");
+const QRegExp YOUTUBE_SHARING_RE("(http(s|)://(www.|m.|)youtube.com/(v/|.+)(v=|)|http://youtu.be/)", Qt::CaseInsensitive);
+const QRegExp DAILYMOTION_SHARING_RE("(http(s|)://(www.|)dailymotion.com/video/|http://dai.ly/)\\w+", Qt::CaseInsensitive);
+const QRegExp VIMEO_SHARING_RE("http(s|)://vimeo.com/\\d+", Qt::CaseInsensitive);
 
 const QString FACEBOOK_CLIENT_ID("385476614847489");
 const QString FACEBOOK_CLIENT_SECRET("711d38a113d298af9348386957c524e5");
@@ -43,8 +43,8 @@ Sharing::Sharing(QObject *parent) :
     m_videoCache(new QList< QSharedPointer<VideoItem> >),
     m_busy(false)
 {
-    if (!sharingInstance) {
-        sharingInstance = this;
+    if (!self) {
+        self = this;
     }
 }
 
@@ -53,7 +53,7 @@ Sharing::~Sharing() {
 }
 
 Sharing* Sharing::instance() {
-    return sharingInstance;
+    return !self ? new Sharing : self;
 }
 
 void Sharing::clearCache() {
@@ -147,7 +147,7 @@ void Sharing::getTwitterAuthUrl() {
     QMap<QString, QString> params;
     params.insert("oauth_callback", REDIRECT_URI);
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     request.setRawHeader("Authorization", this->getTwitterOAuthHeader("GET", url, params));
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(checkTwitterAuthUrl()));
@@ -208,7 +208,7 @@ void Sharing::signInToTwitter(const QUrl &response) {
         params.insert("oauth_token_secret", this->twitterRequestSecret());
         params.insert("oauth_verifier", verifier);
         QNetworkRequest request(url);
-        request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+        request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
         request.setRawHeader("Authorization", this->getTwitterOAuthHeader("GET", url, params));
         QNetworkReply *reply = this->networkAccessManager()->get(request);
         this->connect(reply, SIGNAL(finished()), this, SLOT(checkIfSignedInToTwitter()));
@@ -324,7 +324,7 @@ void Sharing::postToFacebook() {
             + "&description=" + m_post.value("description").toString().toUtf8();
 
     QNetworkRequest request(QUrl("https://graph.facebook.com/me/feed"));
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     request.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
     QNetworkReply *reply = this->networkAccessManager()->post(request, postData);
     this->connect(reply, SIGNAL(finished()), this, SLOT(facebookPostFinished()));
@@ -375,7 +375,7 @@ void Sharing::postToTwitter() {
     QMap<QString, QString> params;
     params.insert("status", m_post.value("body").toString());
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     request.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
     request.setRawHeader("Authorization", this->getTwitterOAuthHeader("POST", url, params));
     QNetworkReply *reply = this->networkAccessManager()->post(request, "status=" + m_post.value("body").toString().toUtf8().toPercentEncoding());
@@ -468,7 +468,7 @@ void Sharing::getVideosFromFacebook() {
     url.addQueryItem("access_token", this->facebookToken());
 #endif
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(checkFacebookVideos()));
     this->disconnect(this, SIGNAL(signedInToFacebook(QString)), this, SLOT(getVideosFromFacebook()));
@@ -568,7 +568,7 @@ void Sharing::getVideosFromTwitter() {
     }
 #endif
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     request.setRawHeader("Authorization", this->getTwitterOAuthHeader("GET", url, QMap<QString, QString>()));
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(checkTwitterVideos()));
