@@ -214,7 +214,6 @@ QScriptValue UrlGrabber::getYouTubeDecryptionFunction(const QUrl &playerUrl) {
     }
 
     QNetworkRequest request(playerUrl);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(addYouTubeDecryptionFunctionToCache()));
     this->connect(this, SIGNAL(currentOperationCancelled()), reply, SLOT(deleteLater()));
@@ -351,7 +350,7 @@ void UrlGrabber::getYouTubeVideoUrl(const QString &id) {
 }
 
 void UrlGrabber::getYouTubeVideoInfoPage(const QString &id, const char *slot) {
-    QUrl url("http://www.youtube.com/get_video_info");
+    QUrl url("https://www.youtube.com/get_video_info");
 #if QT_VERSION >= 0x050000
     QUrlQuery query;
     query.addQueryItem("video_id", id);
@@ -370,7 +369,6 @@ void UrlGrabber::getYouTubeVideoInfoPage(const QString &id, const char *slot) {
     url.addQueryItem("hl", "en");
 #endif
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, slot);
     this->connect(this, SIGNAL(currentOperationCancelled()), reply, SLOT(deleteLater()));
@@ -437,7 +435,6 @@ void UrlGrabber::getYouTubeVideoWebPage(const QString &id, const char *slot) {
     url.addQueryItem("has_verified", "1");
 #endif
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, slot);
     this->connect(this, SIGNAL(currentOperationCancelled()), reply, SLOT(deleteLater()));
