@@ -4,6 +4,9 @@
 #include <QNetworkReply>
 #include <QNetworkRequest>
 #include <QTimer>
+#if QT_VERSION >= 0x050000
+#include <QUrlQuery>
+#endif
 
 YouTubePlaylistListModel::YouTubePlaylistListModel(QObject *parent) :
     AbstractPlaylistListModel(parent),
@@ -42,9 +45,13 @@ void YouTubePlaylistListModel::getPlaylists(QUrl feed) {
     else {
         feed = this->feed();
     }
-
+#if QT_VERSION >= 0x050000
+    QUrlQuery query(feed);
+    query.addQueryItem("fields", YOUTUBE_PLAYLIST_FIELDS);
+    feed.setQuery(query);
+#else
     feed.addQueryItem("fields", YOUTUBE_PLAYLIST_FIELDS);
-
+#endif
     this->setLoading(true);
     QNetworkReply *reply = YouTube::instance()->createReply(feed, this->offset());
     reply->setParent(this);
