@@ -25,6 +25,7 @@ protected:
     void mouseReleaseEvent(QMouseEvent *event);
     void leaveEvent(QEvent *event);
     void paintEvent(QPaintEvent *event);
+    void timerEvent(QTimerEvent *event);
 
 signals:
     void clicked();
@@ -34,6 +35,7 @@ private:
     QImage m_image;
     bool m_interactive;
     bool m_pressed;
+    bool m_allowClick;
 };
 
 #endif // AVATARLABEL_H
