@@ -3,7 +3,6 @@
 
 #include "stackedwindow.h"
 
-class Session;
 class DailymotionUserListModel;
 class ListView;
 class QLabel;
@@ -14,8 +13,8 @@ class DailymotionUserListWindow : public StackedWindow
     Q_OBJECT
 
 public:
-    explicit DailymotionUserListWindow(Session *session, QWidget *parent);
-    void setFeed(const QString &feed);
+    explicit DailymotionUserListWindow(QWidget *parent);
+    void setFeed(const QUrl &feed);
     void search(const QString &query);
 
 private:
