@@ -14,14 +14,17 @@
 #include "../base/transfermanager.h"
 #include "../base/playbacklistmodel.h"
 #include "../base/urlgrabber.h"
+#include "../base/utils.h"
 #include "windowstack.h"
 #include "../base/videoitem.h"
 #include "thumbnaillabel.h"
 #include "ratingindicator.h"
+#include "resourceloader.h"
 #include <QAction>
 #include <QLabel>
 #include <QScrollArea>
 #include <QGridLayout>
+#include <QDesktopServices>
 #include <QMaemo5Style>
 
 DailymotionVideoDescriptionTab::DailymotionVideoDescriptionTab(QSharedPointer<VideoItem> video, QWidget *parent) :
@@ -40,7 +43,7 @@ DailymotionVideoDescriptionTab::DailymotionVideoDescriptionTab(QSharedPointer<Vi
     m_titleLabel(new QLabel(m_video.data()->title(), this)),
     m_dateLabel(new QLabel(QString("%1 - %2").arg(m_video.data()->date()).arg(m_video.data()->artist()), this)),
     m_viewsLabel(new QLabel(QString("%1   <font color='%2'>%3</font>").arg(tr("Views")).arg(QMaemo5Style::standardColor("SecondaryTextColor").name()).arg(m_video.data()->viewCount()), this)),
-    m_descriptionLabel(new QLabel(QString("%1<br><font color='%2'>%3</font>").arg(tr("Description")).arg(QMaemo5Style::standardColor("SecondaryTextColor").name()).arg(m_video.data()->description().isEmpty() ? tr("No description") : m_video.data()->description()), this)),
+    m_descriptionLabel(new QLabel(QString("%1<br><font color='%2'>%3</font>").arg(tr("Description")).arg(QMaemo5Style::standardColor("SecondaryTextColor").name()).arg(m_video.data()->description().isEmpty() ? tr("No description") : Utils::toRichText(m_video.data()->description())), this)),
     m_tagsLabel(new QLabel(this->tagsToString(m_video.data()->tags()), this)),
     m_scrollArea(new QScrollArea(this)),
     m_grid(new QGridLayout(this))
@@ -88,6 +91,7 @@ DailymotionVideoDescriptionTab::DailymotionVideoDescriptionTab(QSharedPointer<Vi
     this->connect(m_videoDownloadAction, SIGNAL(triggered()), this, SLOT(addVideoDownload()));
     this->connect(m_audioDownloadAction, SIGNAL(triggered()), this, SLOT(addAudioDownload()));
     this->connect(m_shareAction, SIGNAL(triggered()), this, SLOT(showShareDialog()));
+    this->connect(m_descriptionLabel, SIGNAL(linkActivated(QString)), this, SLOT(parseActivatedLink(QString)));
     this->connect(m_tagsLabel, SIGNAL(linkActivated(QString)), this, SLOT(search(QString)));
     this->connect(m_video.data(), SIGNAL(favouriteChanged(bool)), this, SLOT(onFavouriteChanged(bool)));
 
@@ -261,6 +265,12 @@ void DailymotionVideoDescriptionTab::showUserChannel() {
     window->show();
 }
 
+void DailymotionVideoDescriptionTab::parseActivatedLink(const QString &link) {
+    if (!ResourceLoader::instance()->display(link, false)) {
+        QDesktopServices::openUrl(link);
+    }
+}
+
 void DailymotionVideoDescriptionTab::search(const QString &query) {
     DailymotionVideoListWindow *window = new DailymotionVideoListWindow(WindowStack::instance()->currentWindow());
     window->search(query, Settings::instance()->searchOrder(), Settings::instance()->languageFilter());
