@@ -32,7 +32,8 @@ private:
     QCheckBox *m_youtube144Checkbox;
     QCheckBox *m_dailymotion720Checkbox;
     QCheckBox *m_dailymotion480Checkbox;
-    QCheckBox *m_dailymotionNormalCheckbox;
+    QCheckBox *m_dailymotion384Checkbox;
+    QCheckBox *m_dailymotion240Checkbox;
     QCheckBox *m_vimeo720Checkbox;
     QCheckBox *m_vimeo360Checkbox;
     QCheckBox *m_vimeoMobileCheckbox;
