@@ -13,6 +13,7 @@
 #include <QAction>
 #include <QLabel>
 #include <QMenuBar>
+#include <QMaemo5Style>
 
 PlaybackQueueWindow::PlaybackQueueWindow(QWidget *parent) :
     StackedWindow(parent),
@@ -25,7 +26,7 @@ PlaybackQueueWindow::PlaybackQueueWindow(QWidget *parent) :
     m_removeContextAction(m_contextMenu->addAction(tr("Remove"), this, SLOT(removeVideo()))),
     m_videoDownloadContextAction(m_contextMenu->addAction(tr("Download"), this, SLOT(addVideoDownload()))),
     m_audioDownloadContextAction(m_contextMenu->addAction(tr("Download (audio)"), this, SLOT(addAudioDownload()))),
-    m_noResultsLabel(new QLabel(QString("<p style='color:#4d4d4d;font-size:40px;'><center><b>%1</b></center></p>").arg(tr("No videos queued")), this))
+    m_noResultsLabel(new QLabel(QString("<p style='color:%1;font-size:40px;'><center><b>%2</b></center></p>").arg(QMaemo5Style::standardColor("SecondaryTextColor").name()).arg(tr("No videos queued")), this))
 {
     this->setWindowTitle(tr("Playback queue"));
     this->setCentralWidget(m_listView);
