@@ -6,8 +6,10 @@
 #include "../base/vimeo.h"
 #include "mediaplayerselector.h"
 #include "concurrenttransfersselector.h"
+#include "connectionsselector.h"
 #include "screenorientationselector.h"
 #include "languageselector.h"
+#include "subtitlesselector.h"
 #include "playbackqualitydialog.h"
 #include "downloadqualitydialog.h"
 #include "searchoptionsdialog.h"
@@ -25,8 +27,9 @@ SettingsDialog::SettingsDialog(QWidget *parent) :
     AbstractDialog(parent),
     m_transferStatusCheckbox(new QCheckBox(tr("Start transfers automatically"), this)),
     m_safeSearchCheckbox(new QCheckBox(tr("Safe search"), this)),
-    m_eventFeedCheckbox(new QCheckBox(tr("Publish latest videos to event feed"))),
-    m_clipboardCheckbox(new QCheckBox(tr("Monitor clipboard for video URLs"))),
+    m_eventFeedCheckbox(new QCheckBox(tr("Publish latest videos to event feed"), this)),
+    m_clipboardCheckbox(new QCheckBox(tr("Monitor clipboard for video URLs"), this)),
+    m_subtitlesCheckbox(new QCheckBox(tr("Download subtitles"), this)),
     m_searchButton(new QPushButton(tr("Search dialog options"), this)),
     m_playbackButton(new QPushButton(tr("Playback quality"), this)),
     m_downloadButton(new QPushButton(tr("Download quality"), this)),
@@ -34,6 +37,8 @@ SettingsDialog::SettingsDialog(QWidget *parent) :
     m_downloadFolderSelector(new QMaemo5ValueButton(tr("Download folder"), this)),
     m_mediaPlayerSelector(new MediaPlayerSelector(tr("Media player"), this)),
     m_concurrentSelector(new ConcurrentTransfersSelector(tr("Concurrent transfers"), this)),
+    m_connectionsSelector(new ConnectionsSelector(tr("Connections per transfer"), this)),
+    m_subtitlesSelector(new SubtitlesSelector(tr("Subtitles language"), this)),
     m_orientationSelector(new ScreenOrientationSelector(tr("Screen orientation"), this)),
     m_languageSelector(new LanguageSelector(tr("Language"), true, this)),
     m_mediaPlayerCommandEdit(new QLineEdit(Settings::instance()->mediaPlayerCommand(), this)),
@@ -54,7 +59,7 @@ SettingsDialog::SettingsDialog(QWidget *parent) :
 
     QWidget *scrollWidget = new QWidget(m_scrollArea);
     QVBoxLayout *vbox = new QVBoxLayout(scrollWidget);
-
+    vbox->setContentsMargins(0, 0, 0, 0);
     vbox->addWidget(new SeparatorLabel(tr("Media/content"), this));
     vbox->addWidget(m_downloadFolderSelector);
     vbox->addWidget(m_mediaPlayerSelector);
@@ -66,8 +71,11 @@ SettingsDialog::SettingsDialog(QWidget *parent) :
     vbox->addWidget(m_safeSearchCheckbox);
     vbox->addWidget(m_searchButton);
     vbox->addWidget(new SeparatorLabel(tr("Transfers"), this));
-    vbox->addWidget(m_concurrentSelector);
     vbox->addWidget(m_transferStatusCheckbox);
+    vbox->addWidget(m_concurrentSelector);
+    vbox->addWidget(m_connectionsSelector);
+    vbox->addWidget(m_subtitlesCheckbox);
+    vbox->addWidget(m_subtitlesSelector);
     vbox->addWidget(new SeparatorLabel(tr("Event feed"), this));
     vbox->addWidget(m_eventFeedCheckbox);
 
@@ -141,10 +149,13 @@ void SettingsDialog::loadSettings() {
     m_safeSearchCheckbox->setChecked(Settings::instance()->safeSearch());
     m_eventFeedCheckbox->setChecked(m_eventFeedEnabled = Settings::instance()->eventFeedEnabled());
     m_clipboardCheckbox->setChecked(Settings::instance()->monitorClipboard());
+    m_subtitlesCheckbox->setChecked(Settings::instance()->downloadSubtitles());
     m_downloadPath = Settings::instance()->downloadPath();
     m_downloadFolderSelector->setValueText(m_downloadPath);
     m_mediaPlayerSelector->setValue(Settings::instance()->mediaPlayer());
     m_concurrentSelector->setValue(Settings::instance()->maximumConcurrentTransfers());
+    m_connectionsSelector->setValue(Settings::instance()->maximumConnectionsPerTransfer());
+    m_subtitlesSelector->setValue(Settings::instance()->subtitlesLanguage());
     m_orientationSelector->setValue(Settings::instance()->screenOrientation());
     m_languageSelector->setValue(Settings::instance()->language());
     m_mediaPlayerCommandEdit->setEnabled(Settings::instance()->mediaPlayer() == "other");
@@ -155,10 +166,13 @@ void SettingsDialog::saveSettings() {
     Settings::instance()->setSafeSearch(m_safeSearchCheckbox->isChecked());
     Settings::instance()->setEventFeedEnabled(m_eventFeedCheckbox->isChecked());
     Settings::instance()->setMonitorClipboard(m_clipboardCheckbox->isChecked());
+    Settings::instance()->setDownloadSubtitles(m_subtitlesCheckbox->isChecked());
     Settings::instance()->setDownloadPath(m_downloadPath);
     Settings::instance()->setMediaPlayer((m_mediaPlayerSelector->currentValue() == "other") && (m_mediaPlayerCommandEdit->text().isEmpty()) ? "mediaplayer" : m_mediaPlayerSelector->currentValue());
     Settings::instance()->setMediaPlayerCommand(m_mediaPlayerCommandEdit->text());
     Settings::instance()->setMaximumConcurrentTransfers(m_concurrentSelector->currentValue());
+    Settings::instance()->setMaximumConnectionsPerTransfer(m_connectionsSelector->currentValue());
+    Settings::instance()->setSubtitlesLanguage(m_subtitlesSelector->currentValue());
     Settings::instance()->setScreenOrientation(m_orientationSelector->currentValue());
     Settings::instance()->setLanguage(m_languageSelector->currentValue());
 
