@@ -5,7 +5,6 @@
 #include <QWidget>
 
 class SocialVideoListModel;
-class Session;
 class ListView;
 class QMaemo5EditBar;
 class QPushButton;
@@ -15,8 +14,9 @@ class QModelIndex;
 class SocialVideoSelectionWindow : public QWidget
 {
     Q_OBJECT
+
 public:
-    explicit SocialVideoSelectionWindow(Session *session, SocialVideoListModel *model, const QString &text, const char* slot, QWidget *parent);
+    explicit SocialVideoSelectionWindow(SocialVideoListModel *model, const QString &text, const char* slot, QWidget *parent);
     ~SocialVideoSelectionWindow();
     void positionAtIndex(const QModelIndex &index);
 
@@ -31,7 +31,6 @@ signals:
     void accepted();
 
 private:
-    Session *m_session;
     SocialVideoListModel *m_model;
     ListView *m_listView;
     QMaemo5EditBar *m_editBar;
