@@ -1,5 +1,5 @@
 #include "transferlistdelegate.h"
-#include "transferlistmodel.h"
+#include "../base/transferitem.h"
 #include <QStyleOptionProgressBar>
 #include <QApplication>
 #include <QPainter>
@@ -26,7 +26,7 @@ void TransferListDelegate::paint(QPainter *painter, const QStyleOptionViewItem &
     textRect.setTop(textRect.top() + 5);
     textRect.setHeight(60);
 
-    painter->drawText(textRect, Qt::TextWordWrap, index.data(TransferListModel::TitleRole).toString());
+    painter->drawText(textRect, Qt::TextWordWrap, index.data(TransferItem::TitleRole).toString());
 
 
     QFont smallFont;
@@ -36,11 +36,11 @@ void TransferListDelegate::paint(QPainter *painter, const QStyleOptionViewItem &
     textRect.moveTop(textRect.bottom());
     textRect.setHeight(40);
 
-    painter->drawText(textRect, Qt::AlignBottom | Qt::TextSingleLine, tr("Priority") + QString(": %1").arg(index.data(TransferListModel::PriorityTextRole).toString()));
+    painter->drawText(textRect, Qt::AlignBottom | Qt::TextSingleLine, tr("Priority") + QString(": %1").arg(index.data(TransferItem::PriorityStringRole).toString()));
 
     textRect.moveTop(textRect.bottom());
 
-    Transfers::TransferStatus status = static_cast<Transfers::TransferStatus>(index.data(TransferListModel::StatusRole).toInt());
+    Transfers::Status status = static_cast<Transfers::Status>(index.data(TransferItem::StatusRole).toInt());
 
     switch (status) {
     case Transfers::Failed:
@@ -53,7 +53,7 @@ void TransferListDelegate::paint(QPainter *painter, const QStyleOptionViewItem &
         painter->setPen(QMaemo5Style::standardColor("ActiveTextColor"));
     }
 
-    painter->drawText(textRect, Qt::AlignBottom | Qt::TextSingleLine, index.data(TransferListModel::StatusTextRole).toString());
+    painter->drawText(textRect, Qt::AlignBottom | Qt::TextSingleLine, index.data(TransferItem::StatusStringRole).toString());
     painter->restore();
 
     QRect progressRect = option.rect;
@@ -62,7 +62,7 @@ void TransferListDelegate::paint(QPainter *painter, const QStyleOptionViewItem &
     progressRect.setTop(progressRect.top() + 30);
     progressRect.setBottom(progressRect.bottom() - 30);
 
-    int progress = index.data(TransferListModel::ProgressRole).toInt();
+    int progress = index.data(TransferItem::ProgressRole).toInt();
 
     QStyleOptionProgressBar progressBar;
     progressBar.rect = progressRect;
