@@ -4,7 +4,6 @@
 #include "abstractdialog.h"
 #include <QVariantMap>
 
-class Session;
 class VimeoUserAlbumListModel;
 class ListView;
 class QDialogButtonBox;
@@ -18,7 +17,7 @@ class VimeoAlbumDialog : public AbstractDialog
     Q_OBJECT
 
 public:
-    explicit VimeoAlbumDialog(Session *session, QWidget *parent = 0);
+    explicit VimeoAlbumDialog(QWidget *parent = 0);
 
 private:
     void setLandscapeLayout();
@@ -34,7 +33,6 @@ signals:
     void addToNewAlbum(const QVariantMap &album);
 
 private:
-    Session *m_session;
     VimeoUserAlbumListModel *m_model;
     ListView *m_listView;
     QDialogButtonBox *m_buttonBox;
