@@ -4,7 +4,6 @@
 #include "abstracttab.h"
 #include "../base/playlistitem.h"
 
-class Session;
 class ListView;
 class VimeoAlbumListModel;
 class QLabel;
@@ -16,8 +15,8 @@ class VimeoAlbumListTab : public AbstractTab
     Q_OBJECT
 
 public:
-    explicit VimeoAlbumListTab(Session *session, QWidget *parent = 0);
-    void setAlbumFeed(const QString &feed);
+    explicit VimeoAlbumListTab(QWidget *parent = 0);
+    void setAlbumFeed(const QUrl &feed);
 
 private:
     void setLandscapeLayout();
@@ -30,7 +29,6 @@ private slots:
     void showAlbum(QSharedPointer<PlaylistItem> album);
 
 private:
-    Session *m_session;
     ListView *m_listView;
     VimeoAlbumListModel *m_model;
     QLabel *m_noResultsLabel;
