@@ -29,8 +29,8 @@ private slots:
     void onProfileError();
     void toggleSubscription();
     void onSubscribedChanged(bool subscribed);
-    void showUserWebsite();
     void showWatchLaterAlbum();
+    void parseActivatedLink(const QString &link);
 
 private:
     QSharedPointer<UserItem> m_user;
