@@ -4,7 +4,6 @@
 #include "abstracttab.h"
 #include "../base/groupitem.h"
 
-class Session;
 class ListView;
 class VimeoUserGroupListModel;
 class QLabel;
@@ -16,8 +15,9 @@ class QModelIndex;
 class VimeoUserGroupListTab : public AbstractTab
 {
     Q_OBJECT
+
 public:
-    explicit VimeoUserGroupListTab(Session *session, QWidget *parent = 0);
+    explicit VimeoUserGroupListTab(QWidget *parent = 0);
 
 private:
     void setLandscapeLayout();
@@ -32,7 +32,6 @@ private slots:
     void leaveGroup();
 
 private:
-    Session *m_session;
     ListView *m_listView;
     VimeoUserGroupListModel *m_model;
     QMenu *m_contextMenu;
