@@ -16,7 +16,7 @@ class VimeoVideoInfoWindow : public StackedWindow
     Q_OBJECT
 
 public:
-    explicit VimeoVideoInfoWindow(Session *session, QSharedPointer<VideoItem> video, QWidget *parent);
+    explicit VimeoVideoInfoWindow(QSharedPointer<VideoItem> video, QWidget *parent);
 
 private:
     void clearMenuActions();
