@@ -5,7 +5,6 @@
 #include "../base/commentitem.h"
 #include "../base/videoitem.h"
 
-class Session;
 class ThumbnailLabel;
 class QTextEdit;
 class QLabel;
@@ -19,7 +18,7 @@ class YouTubeCommentDialog : public AbstractDialog
     Q_OBJECT
 
 public:
-    explicit YouTubeCommentDialog(Session *session, QSharedPointer<VideoItem> video, QSharedPointer<CommentItem> initialComment = QSharedPointer<CommentItem>(), QWidget *parent = 0);
+    explicit YouTubeCommentDialog(QSharedPointer<VideoItem> video, QSharedPointer<CommentItem> initialComment = QSharedPointer<CommentItem>(), QWidget *parent = 0);
 
 private:
     void setLandscapeLayout();
@@ -31,7 +30,6 @@ private slots:
     void submitComment();
 
 private:
-    Session *m_session;
     QSharedPointer<VideoItem> m_video;
     QSharedPointer<CommentItem> m_initialComment;
     QTextEdit *m_commentEdit;
