@@ -29,10 +29,10 @@ private slots:
     void onProfileError();
     void toggleSubscription();
     void onSubscribedChanged(bool subscribed);
-    void showUserWebsite();
     void showUploadDialog();
     void showWatchLaterPlaylist();
     void showWatchHistory();
+    void parseActivatedLink(const QString &link);
     
 private:
     QSharedPointer<UserItem> m_user;
