@@ -37,14 +37,14 @@ private slots:
     void processDailymotionEvents();
     void getVimeoEvents();
     void processVimeoEvents();
-#if (defined (MEEGO_EDITION_HARMATTAN)) || (defined (Q_WS_SAILFISH))
+#if (defined (MEEGO_EDITION_HARMATTAN)) || (defined (SAILFISH_OS))
     void onThumbnailDownloaded();
 #endif
 
 private:
     void init();
     void addEvents();
-#if (defined (MEEGO_EDITION_HARMATTAN)) || (defined (Q_WS_SAILFISH))
+#if (defined (MEEGO_EDITION_HARMATTAN)) || (defined (SAILFISH_OS))
     QString base64SerializedVariant(const QVariant &value) const;
     void downloadThumbnails();
     void clearThumbnails();
